Django utility to retrieve the next or previous object, given a current
object and a queryset.

See http://gregbrown.co.nz/code/django-next-prev/ for more details.

|Circle CI| |codecov| |Latest Version|

Installation
------------

Download the source from https://pypi.python.org/pypi/django-next-prev/
and run ``python setup.py install``, or:

::

    > pip install django-next-prev

Django 1.8 or higher is required.

Quick start
-----------

.. |Circle CI| image:: https://circleci.com/gh/gregplaysguitar/django-next-prev.svg?style=svg
   :target: https://circleci.com/gh/gregplaysguitar/django-next-prev
.. |codecov| image:: https://codecov.io/gh/gregplaysguitar/django-next-prev/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/gregplaysguitar/django-next-prev
.. |Latest Version| image:: https://img.shields.io/pypi/v/django-next-prev.svg?style=flat
   :target: https://pypi.python.org/pypi/django-next-prev/
